require 'test_helper'

class ConfigurationTest < Minitest::Test
  def test_configuration_is_available
    config = Strategize.configuration
    refute config.nil?
  end

  def test_can_configure_from_block
    Strategize.configure do |config|
      config.rule_evaluator = TestRuleEvaluator
    end
  end

  def test_can_add_policy_group
    Strategize.configure do |config|
      config.add_policy_group(:omniauth) do |group|
        group.add DummyPolicy
      end
    end

    refute Strategize.configuration.policy_groups.empty?
  end

  def test_can_get_policy_group
    Strategize.configure do |config|
      config.add_policy_group(:omniauth) do |group|
        group.add DummyPolicy
      end
    end

    policy_group = Strategize.configuration.policy_group(:omniauth)
    policies = policy_group.policies

    assert policy_group.is_a?(Strategize::PolicyGroup)
    assert policies.include?(DummyPolicy)
  end

  def teardown
    Strategize.reset_configuration
  end
end
